nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Gpr2

Struct Gpr2 

#[repr(transparent)]
pub struct Gpr2(pub u32);
GPR2 General Purpose Register

Tuple Fields

0: u32

Implementations

Source

impl Gpr2

pub const fn axbs_l_ahbxl_high_priority(&self) -> AxbsLAhbxlHighPriority

AXBS_L AHBXL master has higher priority.Do not set both DMA and AHBXL to high priority.

pub const fn set_axbs_l_ahbxl_high_priority( &mut self, val: AxbsLAhbxlHighPriority, )

AXBS_L AHBXL master has higher priority.Do not set both DMA and AHBXL to high priority.

pub const fn axbs_l_dma_high_priority(&self) -> AxbsLDmaHighPriority

AXBS_L DMA master has higher priority.Do not set both DMA and AHBXL to high priority.

pub const fn set_axbs_l_dma_high_priority(&mut self, val: AxbsLDmaHighPriority)

AXBS_L DMA master has higher priority.Do not set both DMA and AHBXL to high priority.

pub const fn axbs_l_force_round_robin(&self) -> AxbsLForceRoundRobin

Force Round Robin in AXBS_L

pub const fn set_axbs_l_force_round_robin(&mut self, val: AxbsLForceRoundRobin)

Force Round Robin in AXBS_L

pub const fn axbs_p_m0_high_priority(&self) -> AxbsPM0HighPriority

AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn set_axbs_p_m0_high_priority(&mut self, val: AxbsPM0HighPriority)

AXBS_P M0 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn axbs_p_m1_high_priority(&self) -> AxbsPM1HighPriority

AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn set_axbs_p_m1_high_priority(&mut self, val: AxbsPM1HighPriority)

AXBS_P M1 master has higher priority.Do not set both M1 and M0 to high priority.

pub const fn axbs_p_force_round_robin(&self) -> AxbsPForceRoundRobin

Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.

pub const fn set_axbs_p_force_round_robin(&mut self, val: AxbsPForceRoundRobin)

Force Round Robin in AXBS_P. This bit can override master M0 M1 high priority configuration.

pub const fn canfd_filter_bypass(&self) -> CanfdFilterBypass

Disable CANFD filter

pub const fn set_canfd_filter_bypass(&mut self, val: CanfdFilterBypass)

Disable CANFD filter

pub const fn l2_mem_en_powersaving(&self) -> L2MemEnPowersaving

enable power saving features on L2 memory

pub const fn set_l2_mem_en_powersaving(&mut self, val: L2MemEnPowersaving)

enable power saving features on L2 memory

pub const fn ram_auto_clk_gating_en(&self) -> RamAutoClkGatingEn

Automatically gate off RAM clock when RAM is not accessed.

pub const fn set_ram_auto_clk_gating_en(&mut self, val: RamAutoClkGatingEn)

Automatically gate off RAM clock when RAM is not accessed.

pub const fn l2_mem_deepsleep(&self) -> L2MemDeepsleep

control how memory enter Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low)

pub const fn set_l2_mem_deepsleep(&mut self, val: L2MemDeepsleep)

control how memory enter Deep Sleep mode (shutdown periphery power, but maintain memory contents, outputs of memory are pulled low)

pub const fn mqs_clk_div(&self) -> MqsClkDiv

Divider ratio control for mclk from hmclk. mclk frequency = 1/(n+1) * hmclk frequency.

pub const fn set_mqs_clk_div(&mut self, val: MqsClkDiv)

Divider ratio control for mclk from hmclk. mclk frequency = 1/(n+1) * hmclk frequency.

pub const fn mqs_sw_rst(&self) -> MqsSwRst

MQS software reset

pub const fn set_mqs_sw_rst(&mut self, val: MqsSwRst)

MQS software reset

pub const fn mqs_en(&self) -> MqsEn

MQS enable.

pub const fn set_mqs_en(&mut self, val: MqsEn)

MQS enable.

pub const fn mqs_oversample(&self) -> MqsOversample

Used to control the PWM oversampling rate compared with mclk.

pub const fn set_mqs_oversample(&mut self, val: MqsOversample)

Used to control the PWM oversampling rate compared with mclk.

pub const fn qtimer1_tmr_cnts_freeze(&self) -> Qtimer1TmrCntsFreeze

QTIMER1 timer counter freeze

pub const fn set_qtimer1_tmr_cnts_freeze(&mut self, val: Qtimer1TmrCntsFreeze)

QTIMER1 timer counter freeze

pub const fn qtimer2_tmr_cnts_freeze(&self) -> Qtimer2TmrCntsFreeze

QTIMER2 timer counter freeze

pub const fn set_qtimer2_tmr_cnts_freeze(&mut self, val: Qtimer2TmrCntsFreeze)

QTIMER2 timer counter freeze

pub const fn qtimer3_tmr_cnts_freeze(&self) -> Qtimer3TmrCntsFreeze

QTIMER3 timer counter freeze

pub const fn set_qtimer3_tmr_cnts_freeze(&mut self, val: Qtimer3TmrCntsFreeze)

QTIMER3 timer counter freeze

pub const fn qtimer4_tmr_cnts_freeze(&self) -> Qtimer4TmrCntsFreeze

QTIMER4 timer counter freeze

pub const fn set_qtimer4_tmr_cnts_freeze(&mut self, val: Qtimer4TmrCntsFreeze)

QTIMER4 timer counter freeze